@@ -12,11 +12,28 @@
 # OTHER DEALINGS IN THE SOFTWARE.
 #####################################################################
 
-from pyben.bencode import load, loads, dump, dumps
+"""
+PyBen is a library for decoding/encoding data, with the bencode specification.
+
+Bencode is commonly used for encoding Bittorrent Protocol Metafiles (.torrent).
+"""
+
+from pyben import classes, bencode
+from pyben.bencode import load, loads, dump, dumps, benencode, bendecode
 from pyben.classes import Benencoder, Bendecoder
 
-__version__ = "0.1"
+__version__ = "0.2.1"
 __author__ = "alexpdev"
 
-__all__ = ["dump", "dumps", "load", "loads", "Benencoder", "Bendecoder"]
-
+__all__ = [
+    "Bendecoder",
+    "Benencoder",
+    "bencode",
+    "bendecode",
+    "benencode",
+    "classes",
+    "dump",
+    "dumps",
+    "load",
+    "loads",
+]
